# Changelog

All notable changes to this project will be documented in this file.

## [0.2.0] - 2022/09/07

### Added

- Description: Aliengo MJCF
- Description: Cassie MJCF
- Description: JVRC-1 MJCF
- Example: load in MuJoCo
- Example: load in Pinocchio
- Example: load in PyBullet
- Example: show in MeshCat
- Example: show in MuJoCo
- Example: show in PyBullet
- Example: show in yourdfpy
- New ``REPOSITORY_PATH`` member for each description
- Support MJCF descriptions

### Changed

- ``PATH`` becomes ``PACKAGE_PATH``

### Fixed

- iCub description

## [0.1.1] - 2022/09/06

### Fixed

- Command line usage instructions
- Upload coverage results based on ``USING_COVERAGE`` setting

## [0.1.0] - 2022/09/05

This initial release includes 33 robot descriptions:

- A1
- Aliengo
- Allegro Hand
- ANYmal B
- ANYmal C
- Atlas
- Baxter
- Bolt
- Cassie
- Crazyflie 2.0
- Double Pendulum
- e.DO
- FingerEdu
- Gen2
- HyQ
- iCub
- iiwa 14
- JVRC-1
- Laikago
- Mini Cheetah
- Minitaur
- Panda
- PR2
- Reachy
- Romeo
- Simple Humanoid
- Solo
- TALOS
- TIAGo
- Upkie
- UR10
- UR3
- UR5

### Added

- Caching of git repositories
- Command line to show or animate robot descriptions
- Contributing instructions
- This changelog
